@@ -4,10 +4,10 @@ from typing import Tuple
 import numpy as np
 import pandas as pd
 
-from physicalrisk.handler.constants.constants import RESOLUTION, FUTURE_MONTH
-from physicalrisk.handler.AWSdata import aws
-from physicalrisk.handler.raster_handler.rasterhandler import RasterHandler
-from physicalrisk.handler.printMessageHandler.formatePrint import Formatter
+from handler.constants.constants import RESOLUTION, FUTURE_MONTH
+from handler.AWSdata import aws
+from handler.raster_handler.rasterhandler import RasterHandler
+from handler.printMessageHandler.formatePrint import Formatter
 
 
 class Data_Handler():
